Custom scripts are attached to instances to perform specific actions when the instance is launched. For example, if you are unable to install `cloud-init` inside a guest operating system, you can use a custom script to get a public key and add it to the user account.

Type your script directly into the Customization Script field. If your browser supports the HTML5 File API, you may choose to load your script from a file. The size of your script should not exceed 16 Kb.

An advanced option available when launching an instance is disk partitioning. There are two disk partition options. Selecting Automatic resizes the disk and sets it to a single partition. Selecting Manual allows you to create multiple partitions on the disk.

Check the Configuration Drive box if you want to write metadata to a special configuration drive. When the instance boots, it attaches to the Configuration Drive and accesses the metadata.